@@ -39,7 +39,8 @@ from .requests import check_request, AcceptVerifyRequest
 from .requests import WebQQRequest, PollMessageRequest, HeartbeatRequest
 from .requests import SessMsgRequest, BuddyMsgRequest, GroupMsgRequest
 from .requests import FirstRequest, Login2Request, DiscuMsgRequest
-from .requests import FileRequest
+from .requests import FileRequest, LogoutRequset, FriendListRequest
+from .requests import GroupMembersRequest
 
 import _hash
 import const
@@ -165,6 +166,7 @@ class RequestHub(object):
             buff.close()
         except:
             logger.warn(u"上传图片错误", exc_info=True)
+            return u"[图片获取失败]"
         return ret
 
     def generate_curl(self, url=None, headers=None):
@@ -179,6 +181,8 @@ class RequestHub(object):
         curl.setopt(pycurl.WRITEFUNCTION, buff.write)
         curl.setopt(pycurl.FOLLOWLOCATION, 1)
         curl.setopt(pycurl.MAXREDIRS, 5)
+        curl.setopt(pycurl.TIMEOUT, 3)
+        curl.setopt(pycurl.CONNECTTIMEOUT, 3)
 
         if url:
             curl.setopt(pycurl.URL, url)
@@ -216,7 +220,7 @@ class RequestHub(object):
             curl.perform()
         except:
             logger.warn(u"获取聊天图片错误", exc_info=True)
-            return
+            return u"[图片获取失败]"
         body = buff.getvalue()
         curl.close()
         buff.close()
@@ -247,7 +251,7 @@ class RequestHub(object):
             curl.perform()
         except:
             logger.warn(u"获取群聊天图片错误", exc_info=True)
-            return
+            return u"[图片获取失败]"
         body = buff.getvalue()
         buff.close()
         curl.close()
@@ -284,7 +288,7 @@ class RequestHub(object):
 
     def get_account(self, uin, _type=1):
         """ 获取好友QQ号
-        :param _type: 类型, 1 是好友, 4 是群
+        :param _type: 类型, 1 是好友和讨论组, 4 是群
         """
         # self.load_next_request(QQNumberRequest())
         ret = self.get_friends().get_account(uin)
@@ -462,7 +466,7 @@ class RequestHub(object):
 
         :param uin: 好友uin
         """
-        return self.get_friends().get_show_name()
+        return self.get_friends().get_show_name(uin)
 
     def wrap(self, request, func=None):
         """ 装饰callback
@@ -572,6 +576,7 @@ class RequestHub(object):
     def disconnect(self):
         self.stop_poll = True
         self.poll_and_heart = None
+        self.load_next_request(LogoutRequset())
 
     def send_sess_msg(self, qid, to_uin, content, style=const.DEFAULT_STYLE):
         """ 发送临时消息
@@ -632,3 +637,21 @@ class RequestHub(object):
         """
         return self.load_next_request(AcceptVerifyRequest(uin, account,
                                                           markname))
+
+    def refresh_friend_info(self):
+        self.load_next_request(FriendListRequest(manual=True))
+
+    def refresh_group_info(self, _id):
+        """ 手动刷新某个群的信息
+
+        :param _id: 对应群生成的唯一id
+        """
+        gcode, _type = objects.UniqueIds.get(int(_id))
+        if gcode is None or _type is None:
+            return False, u"没有找到对象"
+
+        if _type != objects.UniqueIds.T_GRP:
+            return False, u"该对象不是群"
+
+        self.load_next_request(GroupMembersRequest(gcode))
+        return True, self.get_groups().get_group_name(gcode)
